@@ -3,9 +3,11 @@ Main interface for sdb service type definitions.
 
 Usage::
 
-    from mypy_boto3.sdb.type_defs import AttributeTypeDef
+    ```python
+    from mypy_boto3_sdb.type_defs import AttributeTypeDef
 
     data: AttributeTypeDef = {...}
+    ```
 """
 import sys
 from typing import List
@@ -18,14 +20,14 @@ else:
 
 __all__ = (
     "AttributeTypeDef",
+    "ItemTypeDef",
+    "ReplaceableAttributeTypeDef",
     "DeletableItemTypeDef",
     "DomainMetadataResultTypeDef",
     "GetAttributesResultTypeDef",
     "ListDomainsResultTypeDef",
     "PaginatorConfigTypeDef",
-    "ReplaceableAttributeTypeDef",
     "ReplaceableItemTypeDef",
-    "ItemTypeDef",
     "SelectResultTypeDef",
     "UpdateConditionTypeDef",
 )
@@ -42,9 +44,35 @@ class AttributeTypeDef(_RequiredAttributeTypeDef, _OptionalAttributeTypeDef):
     pass
 
 
+_RequiredItemTypeDef = TypedDict(
+    "_RequiredItemTypeDef", {"Name": str, "Attributes": List["AttributeTypeDef"]}
+)
+_OptionalItemTypeDef = TypedDict(
+    "_OptionalItemTypeDef", {"AlternateNameEncoding": str}, total=False
+)
+
+
+class ItemTypeDef(_RequiredItemTypeDef, _OptionalItemTypeDef):
+    pass
+
+
+_RequiredReplaceableAttributeTypeDef = TypedDict(
+    "_RequiredReplaceableAttributeTypeDef", {"Name": str, "Value": str}
+)
+_OptionalReplaceableAttributeTypeDef = TypedDict(
+    "_OptionalReplaceableAttributeTypeDef", {"Replace": bool}, total=False
+)
+
+
+class ReplaceableAttributeTypeDef(
+    _RequiredReplaceableAttributeTypeDef, _OptionalReplaceableAttributeTypeDef
+):
+    pass
+
+
 _RequiredDeletableItemTypeDef = TypedDict("_RequiredDeletableItemTypeDef", {"Name": str})
 _OptionalDeletableItemTypeDef = TypedDict(
-    "_OptionalDeletableItemTypeDef", {"Attributes": List[AttributeTypeDef]}, total=False
+    "_OptionalDeletableItemTypeDef", {"Attributes": List["AttributeTypeDef"]}, total=False
 )
 
 
@@ -67,7 +95,7 @@ DomainMetadataResultTypeDef = TypedDict(
 )
 
 GetAttributesResultTypeDef = TypedDict(
-    "GetAttributesResultTypeDef", {"Attributes": List[AttributeTypeDef]}, total=False
+    "GetAttributesResultTypeDef", {"Attributes": List["AttributeTypeDef"]}, total=False
 )
 
 ListDomainsResultTypeDef = TypedDict(
@@ -78,38 +106,12 @@ PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef", {"MaxItems": int, "PageSize": int, "StartingToken": str}, total=False
 )
 
-_RequiredReplaceableAttributeTypeDef = TypedDict(
-    "_RequiredReplaceableAttributeTypeDef", {"Name": str, "Value": str}
-)
-_OptionalReplaceableAttributeTypeDef = TypedDict(
-    "_OptionalReplaceableAttributeTypeDef", {"Replace": bool}, total=False
-)
-
-
-class ReplaceableAttributeTypeDef(
-    _RequiredReplaceableAttributeTypeDef, _OptionalReplaceableAttributeTypeDef
-):
-    pass
-
-
 ReplaceableItemTypeDef = TypedDict(
-    "ReplaceableItemTypeDef", {"Name": str, "Attributes": List[ReplaceableAttributeTypeDef]}
+    "ReplaceableItemTypeDef", {"Name": str, "Attributes": List["ReplaceableAttributeTypeDef"]}
 )
 
-_RequiredItemTypeDef = TypedDict(
-    "_RequiredItemTypeDef", {"Name": str, "Attributes": List[AttributeTypeDef]}
-)
-_OptionalItemTypeDef = TypedDict(
-    "_OptionalItemTypeDef", {"AlternateNameEncoding": str}, total=False
-)
-
-
-class ItemTypeDef(_RequiredItemTypeDef, _OptionalItemTypeDef):
-    pass
-
-
 SelectResultTypeDef = TypedDict(
-    "SelectResultTypeDef", {"Items": List[ItemTypeDef], "NextToken": str}, total=False
+    "SelectResultTypeDef", {"Items": List["ItemTypeDef"], "NextToken": str}, total=False
 )
 
 UpdateConditionTypeDef = TypedDict(
